[V1,2/2] tests/vm2vm_virtio_user: Modify the script sync with testplan

Message ID 20210916164932.77942-3-linglix.chen@intel.com (mailing list archive)
State Accepted
Headers
Series Modify vm2vm_virtio_user testsuite and test_plan |

Checks

Context Check Description
ci/Intel-dts-test success Testing OK
ci/Intel-suite-dts-test fail Testing issues
ci/Intel-doc-dts-test success Testing OK
ci/Intel-dts-doc-test success Testing OK

Commit Message

Lingli Chen Sept. 16, 2021, 4:49 p.m. UTC
  1.Modify case 12, case 14 case name sync with testplan.
2.Modify case 4, case 7, case 8 sync with testplan.

Signed-off-by: Lingli Chen <linglix.chen@intel.com>
---
 tests/TestSuite_vm2vm_virtio_user.py | 38 +++++++++++++---------------
 1 file changed, 18 insertions(+), 20 deletions(-)
  

Comments

Lingli Chen Sept. 27, 2021, 8:33 a.m. UTC | #1
> -----Original Message-----
> From: Chen, LingliX <linglix.chen@intel.com>
> Sent: Friday, September 17, 2021 12:50 AM
> To: dts@dpdk.org
> Cc: Chen, LingliX <linglix.chen@intel.com>
> Subject: [dts][PATCH V1 2/2] tests/vm2vm_virtio_user: Modify the script sync
> with testplan
> 
> 1.Modify case 12, case 14 case name sync with testplan.
> 2.Modify case 4, case 7, case 8 sync with testplan.
> 
> Signed-off-by: Lingli Chen <linglix.chen@intel.com>

Tested-by: Lingli Chen <linglix.chen@intel.com>
  
Wang, Yinan Sept. 29, 2021, 9:13 a.m. UTC | #2
Acked-by:  Yinan Wang <yinan.wang@intel.com>

> -----Original Message-----
> From: dts <dts-bounces@dpdk.org> On Behalf Of Chen, LingliX
> Sent: 2021?9?27? 16:34
> To: dts@dpdk.org
> Subject: Re: [dts] [PATCH V1 2/2] tests/vm2vm_virtio_user: Modify the
> script sync with testplan
> 
> 
> > -----Original Message-----
> > From: Chen, LingliX <linglix.chen@intel.com>
> > Sent: Friday, September 17, 2021 12:50 AM
> > To: dts@dpdk.org
> > Cc: Chen, LingliX <linglix.chen@intel.com>
> > Subject: [dts][PATCH V1 2/2] tests/vm2vm_virtio_user: Modify the script
> sync
> > with testplan
> >
> > 1.Modify case 12, case 14 case name sync with testplan.
> > 2.Modify case 4, case 7, case 8 sync with testplan.
> >
> > Signed-off-by: Lingli Chen <linglix.chen@intel.com>
> 
> Tested-by: Lingli Chen <linglix.chen@intel.com>
  

Patch

diff --git a/tests/TestSuite_vm2vm_virtio_user.py b/tests/TestSuite_vm2vm_virtio_user.py
index bd1c320e..e6c407a8 100644
--- a/tests/TestSuite_vm2vm_virtio_user.py
+++ b/tests/TestSuite_vm2vm_virtio_user.py
@@ -416,7 +416,7 @@  class TestVM2VMVirtioUser(TestCase):
 
     def test_vm2vm_virtio_user_packed_virtqueue_mergeable_path(self):
         """
-        packed virtqueue vm2vm mergeable path test
+        Test Case 1: packed virtqueue vm2vm mergeable path test
         about packed virtqueue path, the 8k length pkt will occupies 1 ring since indirect feature enabled
         """
         small_pkts_num = 251
@@ -444,7 +444,7 @@  class TestVM2VMVirtioUser(TestCase):
 
     def test_vm2vm_virtio_user_packed_virtqueue_inorder_mergeable_path(self):
         """
-        packed virtqueue vm2vm inorder mergeable path test
+        Test Case 2: packed virtqueue vm2vm inorder mergeable path test
         about packed virtqueue path, the 8k length pkt will occupies 5 ring,
         2000,2000,2000,2000 will need 4 consequent ring, still need one ring put header
         so, as the rxt=256, if received pkts include 8k chain pkt, it will received up to 252 pkts
@@ -471,7 +471,7 @@  class TestVM2VMVirtioUser(TestCase):
 
     def test_vm2vm_virtio_user_packed_virtqueue_no_mergeable_path(self):
         """
-        packed virtqueue vm2vm non-mergeable path test
+        Test Case 3: packed virtqueue vm2vm non-mergeable path test
         about non-mergeable path, it can not received large pkts
         """
         small_pkts_num = 251
@@ -497,13 +497,13 @@  class TestVM2VMVirtioUser(TestCase):
 
     def test_vm2vm_virtio_user_packed_virtqueue_inorder_no_mergeable_path(self):
         """
-        packed virtqueue vm2vm inorder non-mergeable path test
+        Test Case 4: packed virtqueue vm2vm inorder non-mergeable path test
         about non-mergeable path, it can not received large pkts
         """
         small_pkts_num = 251
         large_8k_pkts_num = 0
         large_2k_pkts_num = 0
-        path_mode = 'packed_vq=1,mrg_rxbuf=0,in_order=1,vectorized=1'
+        path_mode = 'packed_vq=1,mrg_rxbuf=0,in_order=1'
         extern_params = '--rx-offloads=0x10'
         ringsize = 256
         # get dump pcap file of virtio
@@ -523,8 +523,7 @@  class TestVM2VMVirtioUser(TestCase):
 
     def test_vm2vm_virtio_user_packed_virtqueue_vectorized_path(self):
         """
-        packed virtqueue vm2vm inorder non-mergeable path test
-        about non-mergeable path, it can not received large pkts
+        Test Case 10: packed virtqueue vm2vm vectorized path test
         """
         small_pkts_num = 251
         large_8k_pkts_num = 0
@@ -549,8 +548,7 @@  class TestVM2VMVirtioUser(TestCase):
 
     def test_vm2vm_virtio_user_packed_virtqueue_vectorized_path_ringsize_not_powerof_2(self):
         """
-        packed virtqueue vm2vm inorder non-mergeable path test
-        about non-mergeable path, it can not received large pkts
+        Test Case 11: packed virtqueue vm2vm vectorized path test with ring size is not power of 2
         """
         small_pkts_num = 251
         large_8k_pkts_num = 0
@@ -575,7 +573,7 @@  class TestVM2VMVirtioUser(TestCase):
 
     def test_vm2vm_virtio_user_split_virtqueue_mergeable_path(self):
         """
-        split virtqueue vm2vm mergeable path test
+        Test Case 5: split virtqueue vm2vm mergeable path test
         about split virtqueue path, the 8k length pkt will occupies 1 ring,
         so, as the rxt=256, if received pkts include 8k chain pkt, also will received up to 256 pkts
         """
@@ -604,7 +602,7 @@  class TestVM2VMVirtioUser(TestCase):
 
     def test_vm2vm_virtio_user_split_virtqueue_inorder_mergeable_path(self):
         """
-        split virtqueue vm2vm inorder mergeable path test
+        Test Case 6: split virtqueue vm2vm inorder mergeable path test
         about split virtqueue path, the 8k length pkt will occupies 5 ring,
         2000,2000,2000,2000 will need 4 consequent ring, still need one ring put header
         so, as the rxt=256, if received pkts include 8k chain pkt, it will received up to 252 pkts
@@ -631,13 +629,13 @@  class TestVM2VMVirtioUser(TestCase):
 
     def test_vm2vm_virtio_user_split_virtqueue_no_mergeable_path(self):
         """
-        split virtqueue vm2vm non-mergeable path test
+        Test Case 7: split virtqueue vm2vm non-mergeable path test
         about non-mergeable path, it can not received large pkts
         """
         small_pkts_num = 251
         large_8k_pkts_num = 0
         large_2k_pkts_num = 0
-        path_mode = 'packed_vq=0,mrg_rxbuf=0,in_order=0,vectorized=1'
+        path_mode = 'packed_vq=0,mrg_rxbuf=0,in_order=0'
         ringsize = 256
         extern_params = '--enable-hw-vlan-strip'
         # get dump pcap file of virtio
@@ -656,7 +654,7 @@  class TestVM2VMVirtioUser(TestCase):
 
     def test_vm2vm_virtio_user_split_virtqueue_inorder_no_mergeable_path(self):
         """
-        split virtqueue vm2vm inorder non-mergeable path test
+        Test Case 8: split virtqueue vm2vm inorder non-mergeable path test
         about non-mergeable path, it can not received large pkts
         """
         small_pkts_num = 251
@@ -664,7 +662,7 @@  class TestVM2VMVirtioUser(TestCase):
         large_2k_pkts_num = 0
         path_mode = 'packed_vq=0,mrg_rxbuf=0,in_order=1'
         ringsize = 256
-        extern_params = '--rx-offloads=0x10'
+        extern_params = ''
         # get dump pcap file of virtio
         # the virtio0 will send 283 pkts, but the virtio only will received 251 pkts
         self.logger.info('check pcap file info about virtio')
@@ -681,7 +679,7 @@  class TestVM2VMVirtioUser(TestCase):
 
     def test_vm2vm_virtio_user_split_virtqueue_vector_rx_path(self):
         """
-        split virtqueue vm2vm vector_rx path test
+        Test Case 9: split virtqueue vm2vm vector_rx path test
         about vector_rx path, it can not received large pkts
         """
         small_pkts_num = 251
@@ -753,9 +751,9 @@  class TestVM2VMVirtioUser(TestCase):
                 if driver != driver_now:
                     netdev.bind_driver(driver=driver)
 
-    def test_vm2vm_virtio_user_split_virtqueue_inorder_mergeable_path_with_cbdma(self):
+    def test_vm2vm_virtio_user_split_virtqueue_non_mergeable_path_with_cbdma(self):
         """
         Test Case 12: split virtqueue vm2vm inorder mergeable path multi-queues payload check with cbdma enabled
         """
         self.cbdma_nic_dev_num = 4
         self.get_cbdma_ports_info_and_bind_to_dpdk()
@@ -812,9 +810,9 @@  class TestVM2VMVirtioUser(TestCase):
         self.check_packet_payload_valid_with_cbdma(self.dump_virtio_pcap, total_pkts_num, large_4640_pkts_num, large_64_pkts_num)
         self.logger.info('check pcap file info about vhost')
 
-    def test_vm2vm_virtio_user_packed_virtqueue_inorder_mergeable_path_with_cbdma(self):
+    def test_vm2vm_virtio_user_packed_virtqueue_non_mergeable_path_with_cbdma(self):
         """
         Test Case 14: packed virtqueue vm2vm inorder mergeable path multi-queues payload check with cbdma enabled
         """
         self.cbdma_nic_dev_num = 4
         self.get_cbdma_ports_info_and_bind_to_dpdk()
@@ -753,9 +751,9 @@  class TestVM2VMVirtioUser(TestCase):
         """
-        Test Case 12: split virtqueue vm2vm inorder mergeable path multi-queues payload check with cbdma enabled
+        Test Case 12: split virtqueue vm2vm non-mergeable path multi-queues payload check with cbdma enabled
         """
         self.cbdma_nic_dev_num = 4
@@ -812,9 +810,9 @@  class TestVM2VMVirtioUser(TestCase):
         """
-        Test Case 14: packed virtqueue vm2vm inorder mergeable path multi-queues payload check with cbdma enabled
+        Test Case 14: packed virtqueue vm2vm non-mergeable path multi-queues payload check with cbdma enabled
         """
         self.cbdma_nic_dev_num = 4